@@ -1,3 +1,4 @@
+use cargo_zigbuild::rustc::Rustc;
 use cargo_zigbuild::{Build, Zig};
 use clap::Parser;
 
@@ -9,8 +10,10 @@ use clap::Parser;
     global_setting(clap::AppSettings::DeriveDisplayOrder)
 )]
 pub enum Opt {
-    #[clap(name = "zigbuild")]
+    #[clap(name = "zigbuild", alias = "build")]
     Build(Build),
+    #[clap(name = "rustc")]
+    Rustc(Rustc),
     #[clap(subcommand)]
     Zig(Zig),
 }
@@ -19,6 +22,7 @@ fn main() -> anyhow::Result<()> {
     let opt = Opt::parse();
     match opt {
         Opt::Build(build) => build.execute()?,
+        Opt::Rustc(rustc) => rustc.execute()?,
         Opt::Zig(zig) => zig.execute()?,
     }
     Ok(())
